@@ -1,7 +1,7 @@
 /************************************************************************
  * common.h                                                             *
  *                                                                      *
- * Copyright (C) 2002 - 2017 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2018 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous *
  *                  mode detection and handling.             *
  *                                                           *
- * Version:         1.0.8                                    *
+ * Version:         1.0.9                                    *
  *                                                           *
  * --------------------------------------------------------- *
  *                                                           *
@@ -57,5 +57,7 @@ extern int dFlag;		/* Interface disable flag. */
 extern int iFlag;		/* Interface metrics flag. */
 extern int FFlag;		/* Foreground process flag. */
 extern int nullFlag;		/* Dummy interface flag - for processFlags(). */
+extern int hFlag;		/* SIGHUP flag. */
+extern int bFlag;		/* Bond interface flag. */
 
 #endif /* COMMON_H */
