@@ -1,7 +1,7 @@
 /************************************************************************
  * evtloop.c                                                            *
  *                                                                      *
- * Copyright (C) 2002 - 2017 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2018 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous *
  *                  mode detection and handling.             *
  *                                                           *
- * Version:         1.0.8                                    *
+ * Version:         1.0.9                                    *
  *                                                           *
  * --------------------------------------------------------- *
  *                                                           *
@@ -84,6 +84,11 @@ int evtLoop( sigset_t mask, int promisc )
             exit( EXIT_FAILURE );
          }
 
+        if( sigNum == SIGHUP )
+	{
+            hFlag = TRUE; 
+	 }
+
         /*
          * We caught SIGINT or SIGTERM - exit, and return to main() context.
          */
