@@ -1,7 +1,7 @@
 /************************************************************************
  * filestat.c                                                           *
  *                                                                      *
- * Copyright (C) 2002 - 2017 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2018 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous *
  *                  mode detection and handling.             *
  *                                                           *
- * Version:         1.0.8                                    *
+ * Version:         1.0.9                                    *
  *                                                           *
  * --------------------------------------------------------- *
  *                                                           *
@@ -235,13 +235,13 @@ FILE *statFile( char *path, struct fsObj fsObjAttrs )
      */
     if( objAttrs.regMode == TRUE )
     {
-        if( ( ( ( fileAttrs.st_mode ) & ( R_GRP_OTH | W_GRP_OTH | X_USR_GRP_OTH ) ) && ALLPERMS ) )
+        if( ( ( ( fileAttrs.st_mode ) & ( W_GRP_OTH) ) && ALLPERMS ) )
         {
-	    fprintf( stderr, "ifchk[%d]: WARNING: %s permissions are not mode 0600\n",
-	                                                            getpid(), filePath );
+	    fprintf( stderr, "ifchk[%d]: WARNING: %s: writable by group and/or other\n",
+	                                                              getpid(), filePath );
 
-            if( ( writeLog( LOG_WARNING, "WARNING: %s permissions are not mode 0600\n",
-                                                                      filePath ) ) != 0 )
+            if( ( writeLog( LOG_WARNING, "WARNING: %s: writable by group and/or other\n",
+                                                                        filePath ) ) != 0 )
             {
                 exit( EXIT_FAILURE );
              }
