@@ -1,7 +1,7 @@
 /************************************************************************
  * linux.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2017 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2018 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous   *
  *                  mode detection and handling.               *
  *                                                             *
- * Version:         1.0.8                                      *
+ * Version:         1.0.9                                      *
  *                                                             *
  * ----------------------------------------------------------- *
  *                                                             *
@@ -50,6 +50,12 @@
 
 #include "linux.h"
 
+/***********************
+ * global declarations *
+ ***********************/
+
+int bFlag = FALSE;
+
 
 /*************************************************************
  * ifStat()    - Establishes a communication channel between *
@@ -70,6 +76,11 @@ int ifStat( void )
     struct sysfs_class *class;			/* sysfs class structure. */
     struct dlist *classDev;			/* sysfs class device list. */
     char pathName[SYSFS_PATH_MAX] = "";		/* Pathname of sysfs object to query. */
+    char *bondPtr = NULL;			/* Pathname of bond interface sysfs object to query. */
+    char slaveFile[BONDBUFSZ] = "";		/* Buffer for sysfs filesystem bonding interface slaves. */
+    FILE *bondslavefd = NULL;			/* File pointer that points to bonding interface slaves. */ 
+    char buf[BONDBUFSZ] = "";			/* Buffer for sysfs filesystem bonding interface slaves. */
+    char *nlPtr = NULL;				/* Ptr for trailing newline processing. */
     int ifCount = 0;				/* Interface count. */
     struct sysfs_attribute *sysAttr;		/* sysfs attribute to open (e.g., /sys/class/net/eth0/flags). */
     char *endPtr = NULL;			/* For strtol(). */
@@ -82,9 +93,29 @@ int ifStat( void )
     struct ifList *new = NULL;			/* Constructed locally & passed \ */
     struct ifList *cur = NULL;			/* to ifMetric() for processing \ */
     struct ifList *freeList = NULL;		/* & output. */
+    struct fsObj slaveObject;			/* File attribute checking policy. */ 
+
+    /*
+     * Reset all statFile() file checks.
+     */
+    slaveObject.openRead = FALSE;
+    slaveObject.procLen = FALSE;
+    slaveObject.procOwner = FALSE;
+    slaveObject.procMode = FALSE;
+    slaveObject.regLen = FALSE;
+    slaveObject.regMode = FALSE;
 
     memset( mntPath, '\000', sizeof( mntPath ) );
 
+    /*
+     * Preset the file query policy for fileStat(), below. Specifically,
+     * we want to probe the sysfs file attributes of bonding interface
+     * slaves (e.g., em1, em2), if any.
+     */
+    slaveObject.openRead = TRUE;
+    slaveObject.regLen = TRUE;
+    slaveObject.regMode = TRUE;
+
     /*
      * Determine the sysfs mount point.
      */
@@ -159,6 +190,52 @@ int ifStat( void )
         strncat( pathName, "/", ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
         strncat( pathName, "flags", ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
 
+        /*
+         * Handle logical bonding interfaces (e.g., bond0), if present.
+         */
+        if( ( bondPtr = strstr( pathName, "bond" ) ) != NULL )
+        {
+            bFlag = TRUE;
+
+            /*
+	     * Build a pathname to the current bonding interface's slave sysfs
+	     * file (e.g., /sys/devices/virtual/net/bond0/bonding/slaves).
+	     * This file describes the slave interfaces (e.g., em1, em2) for
+	     * which the bond is master.
+	     */
+            strncpy( slaveFile, "/sys/devices/virtual/net/", sizeof( slaveFile ) );
+            strncat( slaveFile, class -> name, sizeof( slaveFile ) );
+            strncat( slaveFile, "/bonding/slaves", sizeof( slaveFile ) );
+
+	    /*
+             * Prepare to securely open the current bonding slave's sysfs file.
+	     */
+            if( ( bondslavefd = statFile( slaveFile, slaveObject ) ) == NULL )
+            {
+                return (-1);
+             }
+
+            /*
+	     * Once opened, read the file's contents (e.g., "em1 em2").
+	     */
+            while( ( fgets( buf, sizeof( buf ), bondslavefd ) ) != NULL )
+            {
+                if( ( nlPtr = strchr( buf, '\n' ) ) )
+                {
+                    *nlPtr = '\000';
+                 }
+             }
+
+            /*
+	     * Once read, close the slave sysfs file.
+	     */
+            if( fclose( bondslavefd ) != 0 )
+            {
+                errHandler( "ERROR: fclose(): could not close %s: %s\n", slaveFile, strerror( errno ) );
+                return (-1);
+             }
+         }
+	 
         /*
 	 * Open the current interface's sysfs flags file.
 	 */
@@ -338,6 +415,8 @@ int ifStat( void )
 	 * Close the current interface's sysfs flags file.
 	 */
         sysfs_close_attribute( sysAttr );
+
+        bFlag = FALSE;
      }
 
     /*
